@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 
 ───│─────────────────────────────────────
@@ -13,9 +14,9 @@
 
 CONFIG 
 
-    FLASK_DOES_HUEY_URL
+    FLASK_DOES_HUEY_URL or REDIS_URL
     FLASK_DOES_HUEY_HOST or REDIS_HOST
-    FLASK_DOES_HUEY_PORT or REDIS_PORT\
+    FLASK_DOES_HUEY_PORT or REDIS_PORT
     FLASK_DOES_HUEY_DB or REDIS_DB
     FLASK_DOES_HUEY_USERNAME or REDIS_USERNAME
     FLASK_DOES_HUEY_PASSWORD or REDIS_PASSWORD
@@ -40,7 +41,8 @@ from os import environ as env
 from huey import RedisHuey
 
 
-__version__ = '0.5.1'
+__version__ = '0.5.2'
+__author__ = '@jthop'
 
 
 class HueyFactory(object):
